clear
rng(1);

% Figures 7 and A7

%% parameters
% Columns: mu1 mu2 bt1 bt2 wi1 wi2 p(N1) gamma

% Academic Journal sample estimates
AJParam=[8.58 99999 7.89 9999 5.65 99999 1.00 1.00;... % 1N Gamma=1    (Figure 7a, A7a)
         1.30 19.18 2.70 5.86 0.05 12.73 0.86 0.10;... % 2N            (Figure 7a, A7b)
         3.09 20.43 2.48 5.44 0.05 12.41 0.69 1.00;... % 2N Gamma=1    (Figure A7a)
         5.19 99999 9.00 9999 5.47 99999 1.00 0.25];   % 1N            (Figure A7b) 

% Nudge Unit sample estimates
NUParam=[1.50 9999 3.04 9999 2.38 999 1.00 1.00;... % 1N Gamma=1 (Figure 7b)
         0.35 5.09 0.41 4.64 0.23 6.4 0.78 1.00];   % 2N Gamma=1 (Figure 7b)

%% load data
AJ=readtable('cleaned_data/MATLAB/Academic Journals.csv');
AJ=sortrows(AJ,'trialnumber');
AJTrial=table2array(AJ(:,{'trialnumber'}));
AJTrial=round(AJTrial*100);
AJTrial=findgroups(AJTrial);
AJTE=table2array(AJ(:,{'treatmenteffect'}));
AJSE=table2array(AJ(:,{'SE'}));

NU=readtable('cleaned_data/MATLAB/Nudge Units.csv');
NU=sortrows(NU,'trialnumber');
NUTrial=table2array(NU(:,{'trialnumber'}));
NUTrial=round(NUTrial*100);
NUTrial=findgroups(NUTrial);
NUTE=table2array(NU(:,{'treatmenteffect'}));
NUSE=table2array(NU(:,{'SE'}));

%% simulate and plot densities
nsim=1000000;

% Figure 7a
AJx=-10:0.01:max(AJTE);
index=randsample(max(AJTrial),nsim,true); % Randomly draw trials for the number of arms and SEs to reflect the empirical distribution
for r=[1,2]
    % Load parameters
    mu1=AJParam(r,1);
    mu2=AJParam(r,2);
    sd1=AJParam(r,3);
    sd2=AJParam(r,4);
    wi1=AJParam(r,5);
    wi2=AJParam(r,6);
    q=AJParam(r,7);
    gamma=AJParam(r,8);
    
    mix=binornd(1,q,nsim,1);                                % 1{Draw trial effect around mu1}
    AJSimTrialTE=normrnd(mu1,sd1,nsim,1);                   % Draw trial-level base effects around mu1
    AJSimTrialTE(mix==0)=normrnd(mu2,sd2,sum(mix==0),1);    % Draw trial-level base effects around mu2
    simid=[1:nsim]';                                        % Simulated trial ID numbers
    AJSimTE=[];                                             % To collect published effect sizes
    for m=1:max(AJTrial)
        arms=sum(AJTrial==m);                               % Number of arms in this trial
        cond=index==m;                                      % Index of times this trial was randomly drawn
        semat=repelem(AJSE(AJTrial==m),sum(cond),1);        % Empirical SEs (length=number of arms * number of times this trial was drawn)
        idmat=repmat(simid(cond),arms,1);                   % Simulated trial ID numbers
        base=repmat(AJSimTrialTE(cond),arms,1);             % Base trial-level effects
        mixind=repmat(mix(cond),arms,1);                    % Indicator for whether the base trial-level effect was drawn around mu1 or mu2
        temat=normrnd(base,(semat.^2 + wi1^2).^0.5);        % Draw treatment-level effects for trials drawn around mu1   
        temat(mixind==0)=normrnd(base(mixind==0),...
            (semat(mixind==0).^2 + wi2^2).^0.5);            % Draw treatment-level effects for trials drawn around mu2
        sig=temat./semat>=1.96;                             % Indicator for treatment-level significance
        triallevel= [...
            accumarray(idmat,idmat,[],@mean),...
            accumarray(idmat,sig,[],@max),...
        ];                                                  % Collapse to trial-level significance (i.e., at least one treatment arm is significant)
        keep=triallevel(:,1)>0;                             % Filter out missing values
        triallevel=triallevel(keep,:);                      % Filter out missing values
        keep=logical(triallevel(:,2)+...
            (1-triallevel(:,2)).*binornd(1,gamma,size(triallevel(:,2),1),...
            size(triallevel(:,2),2)));                      % Publish significant trials w.p. 1 and insignificant trials w.p. gamma
        keep=repmat(keep,arms,1);                           % Apply publishing rule
        AJSimTE=[AJSimTE;temat(keep==1)];                   % Add to list of published effect sizes
    end
AJSimpdf=fitdist(AJSimTE,'Kernel'); % Fit kernel density
AJSimTEpdf{r}=pdf(AJSimpdf,AJx);    % Pdf
end

% Plot
close
hold on
fig = gcf;
histogram(AJTE,'BinWidth',1,'Normalization','pdf')
plot(AJx,AJSimTEpdf{1},':b','Linewidth',1.5)
plot(AJx,AJSimTEpdf{2},'-r','Linewidth',1.5)
plot(0,0,'w');
axis([-10 35 0 0.15])
xlabel('Treatment effect (pp.)') 
ylabel('Density')
legend({'Empirical histogram','Normal-based meta-analysis (-LLH=267.69)','Mixture of two normals with','publication bias correction (-LLH=211.25)'},...
    'Interpreter','latex','Fontsize',10,'Location','northeast')
set(figure,'PaperSize',[20,20])
fig.PaperPositionMode = 'auto'
fig_pos = fig.PaperPosition;
fig.PaperSize = [fig_pos(3) fig_pos(4)];
print(fig,'./output/figures_final/AJSimDensity_ML2N','-dpdf')
hold off
close



% Figure 7b
NUx=min(NUTE):0.01:max(NUTE);
index=randsample(max(NUTrial),nsim,true);
for r=[1,2]
    mu1=NUParam(r,1);
    mu2=NUParam(r,2);
    sd1=NUParam(r,3);
    sd2=NUParam(r,4);
    wi1=NUParam(r,5);
    wi2=NUParam(r,6);
    q=NUParam(r,7);
    mix=binornd(1,q,nsim,1);
    NUSimTrialTE=normrnd(mu1,sd1,nsim,1); 
    NUSimTrialTE(mix==0)=normrnd(mu2,sd2,sum(mix==0),1);
    NUSimTE=[];
    for m=1:max(NUTrial)
        arms=sum(NUTrial==m);                                
        cond=index==m;                                                
        semat=repelem(NUSE(NUTrial==m),sum(cond),1);                  
        base=repmat(NUSimTrialTE(cond),arms,1);                       
        mixind=repmat(mix(cond),arms,1);                              
        NUSimTE1=normrnd(base(mixind==1),(semat(mixind==1).^2 + wi1^2).^0.5);
        NUSimTE2=normrnd(base(mixind==0),(semat(mixind==0).^2 + wi2^2).^0.5);
        NUSimTE=[NUSimTE;NUSimTE1;NUSimTE2];
    end
NUSimpdf=fitdist(NUSimTE,'Kernel');
NUSimTEpdf{r}=pdf(NUSimpdf,NUx);
end

close
hold on
fig = gcf;
histogram(NUTE,'BinWidth',1,'Normalization','pdf')
plot(NUx,NUSimTEpdf{1},':b','Linewidth',1.5)
plot(NUx,NUSimTEpdf{2},'-r','Linewidth',1.5)
axis([-10 35 0 0.5])
xlabel('Treatment effect (pp.)') 
ylabel('Density')
legend({'Empirical histogram',['Normal-based meta-analysis (-LLH=647.26)'],['Mixture of two normals (-LLH=395.04)']},...
    'Interpreter','latex','Fontsize',10,'Location','northeast')
set(figure,'PaperSize',[20,20])
fig.PaperPositionMode = 'auto'
fig_pos = fig.PaperPosition;
fig.PaperSize = [fig_pos(3) fig_pos(4)];
print(fig,'./output/figures_final/NUSimDensity_ML2N','-dpdf')
hold off
close



% Figure A7a,b
AJx=-10:0.01:max(AJTE);
index=randsample(max(AJTrial),nsim,true);
for r=1:4
    mu1=AJParam(r,1);
    mu2=AJParam(r,2);
    sd1=AJParam(r,3);
    sd2=AJParam(r,4);
    wi1=AJParam(r,5);
    wi2=AJParam(r,6);
    q=AJParam(r,7);
    gamma=AJParam(r,8);
    mix=binornd(1,q,nsim,1); % 1(draw trial effect around mu1)
    AJSimTrialTE=normrnd(mu1,sd1,nsim,1); 
    AJSimTrialTE(mix==0)=normrnd(mu2,sd2,sum(mix==0),1);
    simid=[1:nsim]';
    AJSimTE=[];
    for m=1:max(AJTrial)
        arms=sum(AJTrial==m);                       
        cond=index==m;                                       
        semat=repelem(AJSE(AJTrial==m),sum(cond),1);         
        idmat=repmat(simid(cond),arms,1);
        base=repmat(AJSimTrialTE(cond),arms,1);              
        mixind=repmat(mix(cond),arms,1);                     
        temat=normrnd(base,(semat.^2 + wi1^2).^0.5);            
        temat(mixind==0)=normrnd(base(mixind==0),(semat(mixind==0).^2 + wi2^2).^0.5);
        sig=temat./semat>=1.96;
        triallevel= [...
            accumarray(idmat,idmat,[],@mean),...
            accumarray(idmat,sig,[],@max),...
        ];
        keep=triallevel(:,1)>0;
        triallevel=triallevel(keep,:);
        keep=logical(triallevel(:,2)+(1-triallevel(:,2)).*binornd(1,gamma,size(triallevel(:,2),1),size(triallevel(:,2),2)));
        keep=repmat(keep,arms,1);
        AJSimTE=[AJSimTE;temat(keep==1)];
    end
AJSimpdf=fitdist(AJSimTE,'Kernel');
AJSimTEpdf{r}=pdf(AJSimpdf,AJx);
end

close
hold on
fig = gcf;
histogram(AJTE,'BinWidth',1,'Normalization','pdf')
plot(AJx,AJSimTEpdf{1},':b','Linewidth',1.5)
plot(AJx,AJSimTEpdf{3},'-m','Linewidth',1.5)
axis([-10 35 0 0.15])
xlabel('Treatment effect (pp.)') 
ylabel('Density')
legend({'Empirical histogram','Normal-based meta-analysis (-LLH=267.69)','Mixture of two normals (-LLH=216.59)'},...
    'Interpreter','latex','Fontsize',9,'Location','northeast')
set(figure,'PaperSize',[20,20])
fig.PaperPositionMode = 'auto'
fig_pos = fig.PaperPosition;
fig.PaperSize = [fig_pos(3) fig_pos(4)];
print(fig,'./output/figures_final/AJSimDensity_ML2N_A1','-dpdf')
hold off
close

close
hold on
fig = gcf;
histogram(AJTE,'BinWidth',1,'Normalization','pdf')
plot(AJx,AJSimTEpdf{4},'--','color',[1 50 115]/255,'Linewidth',1.5)
plot(0,0,'w');
plot(AJx,AJSimTEpdf{2},'-r','Linewidth',1.5)
plot(0,0,'w');
axis([-10 35 0 0.15])
xlabel('Treatment effect (pp.)') 
ylabel('Density')
legend({'Empirical histogram','Normal-based meta-analysis with','publication bias correction (-LLH=265.90)','Mixture of two normals with','publication bias correction (-LLH=211.25)'},...
    'Interpreter','latex','Fontsize',9,'Location','northeast')
set(figure,'PaperSize',[20,20])
fig.PaperPositionMode = 'auto'
fig_pos = fig.PaperPosition;
fig.PaperSize = [fig_pos(3) fig_pos(4)];
print(fig,'./output/figures_final/AJSimDensity_ML2N_A2','-dpdf')
hold off
close